@@ -1,6 +1,6 @@
 package XTaTIK;
 
-our $VERSION = '0.001001'; # VERSION
+our $VERSION = '0.001002'; # VERSION
 
 use Mojo::Base 'Mojolicious';
 
@@ -42,7 +42,8 @@ sub startup {
     }
 
     unshift @sass_path,
-            catdir rel2abs(curdir), qw/public  sass  fake-company/
+            catdir rel2abs(curdir),
+                qw/lib XTaTIK public  sass  fake-company/
         unless $ENV{XTATIK_COMPANY}
             and -r catfile $ENV{XTATIK_COMPANY},
                 qw/public  sass  bootstrap  company-variables.scss/;
@@ -62,7 +63,7 @@ sub startup {
         catfile $silo_path, 'public', 'sass';
 
     unshift @sass_path,
-            catdir rel2abs(curdir), qw/public  sass  fake-site/
+            catdir rel2abs(curdir), qw/lib XTaTIK public  sass  fake-site/
         unless -r catfile $silo_path,
                 qw/public  sass  bootstrap  site-variables.scss/;
 
@@ -545,7 +546,11 @@ to C<bug-XTaTIK at rt.cpan.org>
 
 =for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/ZOFFIX"> <img src="http://www.gravatar.com/avatar/328e658ab6b08dfb5c106266a4a5d065?d=http%3A%2F%2Fwww.gravatar.com%2Favatar%2F627d83ef9879f31bdabf448e666a32d5" alt="ZOFFIX" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">ZOFFIX</span> </a> </span>
 
-=for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/CASSI"> <img src="" alt="CASSI" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">CASSI</span> </a> </span> <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/BRYANT"> <img src="" alt="BRYANT" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">BRYANT</span> </a> </span> <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/(HTTPS://GITHUB.COM/CASSI42)"> <img src="" alt="(HTTPS://GITHUB.COM/CASSI42)" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">(HTTPS://GITHUB.COM/CASSI42)</span> </a> </span>
+=over 4
+
+=item * Cassi Bryant (L<https://github.com/cassi42>)
+
+=back
 
 =for html  </div></div>
 
